<?php
ini_set('log_errors', true);
ini_set('error_log', dirname(__FILE__).'/errors.log');

require_once dirname( __FILE__ ) . '/Event.php';

class EventBookingHelpers {

	public static function getTableName($name) {
		global $wpdb;
		   $tables = array(
			'events' => $wpdb->base_prefix . 'ebp_events',
			'eventDates' => $wpdb->base_prefix . 'ebp_events_occurrence',
			'settings' => $wpdb->base_prefix . 'ebp_settings',
			'payments' => $wpdb->base_prefix . 'ebp_payments',
			'coupons' => $wpdb->base_prefix . "ebp_coupons",
			'couponsUsed' => $wpdb->base_prefix . "ebp_coupons_used",
			'eventCoupons' => $wpdb->base_prefix . "ebp_event_coupons",
			'categories' => $wpdb->base_prefix . "ebp_categories",
			'categoryEvents' => $wpdb->base_prefix . "ebp_categories_events",
			'tickets' => $wpdb->base_prefix . "ebp_events_tickets",
			'forms' => $wpdb->base_prefix . "ebp_forms",
			'formsInput' => $wpdb->base_prefix . "ebp_forms_inputs",
			'gateways' => $wpdb->base_prefix . "ebp_gateways",
			'emailTemplates' =>$wpdb->base_prefix . "ebp_email_templates"
		);

    return (string) $tables[$name];
  }

  public static function getIndexedArray($array) {
  	$indexArray = array();
		foreach($array as $item) {
		   array_push($indexArray, $item->id);
		}

  	return $indexArray;
  }

  public static function getElementById($array, $id, $indexedArray = null) {
  	if ($indexedArray == null) $indexedArray = indexEventsAsArray($array);

  	$index = array_search($id, $indexedArray);

  	return $array[$index];

  }

  // backward compatibility
	public static function eventBelongsToCategoreis($id, $categories) {
		return Event::eventBelongsToCategories($id, $categories);
	}

	public static function currencyPricingFormat($cost, $curr, $isBefore, $decimals, $decimalPoint, $thousandSep, $wrapperCost="%cost%") {

		if ($cost == "" || !is_numeric($cost)) $cost = 0;

		$cost = number_format($cost, $decimals, $decimalPoint, $thousandSep);

		$cost = str_replace("%cost%", $cost, $wrapperCost);
		if ($isBefore == "true") {
			return  $curr . '' . $cost;
		} else {
			return $cost . ' ' . $curr;
		}
	}

	public static function generateBookingIdQRCode($id) {
		require_once( ABSPATH . WPINC . '/link-template.php' );
		require_once( ABSPATH . WPINC . '/formatting.php' );
		$link = site_url('/wp-admin/admin.php?page=eventCheckIn%23/'.$id);
		$QRCODE = '<img src="https://chart.googleapis.com/chart?chs=300x300&cht=qr&chl='.htmlentities($link).'" title="Your Booking Id" />';
		return $QRCODE;
	}

	public static function generateBarCode($id){

		require_once( ABSPATH . WPINC . '/link-template.php' );
		require_once( ABSPATH . WPINC . '/formatting.php' );


		$link = site_url('/wp-content/plugins/eventBookingProBarCode/barcode.php?id='.$id);
		$barcode = '<img src="'.$link.'" title="Barcode" />';

		return $barcode;
	}

	public static function generateEmails($paymentID, $type="") {
		global $wpdb;
		$settings = $wpdb->get_row("SELECT currencyBefore, priceDecimalCount, priceDecPoint, priceThousandsSep, currency, dateFormat, dateFormat, refundEmailTemplate, emailTemplate, refundOwnerEmailTemplate, ownerEmailTemplate, emailSubject, SMTP_EMAIL, SMTP_NAME, sendEmailToCustomer, sendEmailToAdmin FROM " . self::getTableName("settings")." where id=1 ");

		$refundEmailTemplate = $settings->refundEmailTemplate;
		$confirmationEmailTemplate = $settings->emailTemplate;
		$refundOwnerEmailTemplate = $settings->refundOwnerEmailTemplate;
		$ownerEmailTemplate = $settings->ownerEmailTemplate;
		$emailSubject = $settings->emailSubject;
		$SMTP_EMAIL = $settings->SMTP_EMAIL;
		$SMTP_NAME = $settings->SMTP_NAME;
		$sendEmailToCustomer = $settings->sendEmailToCustomer;
		$sendEmailToAdmin = $settings->sendEmailToAdmin;
		$currencyBefore = $settings->currencyBefore;
		$priceDecimalCount = $settings->priceDecimalCount;
		$priceDecPoint = $settings->priceDecPoint;
		$priceThousandsSep = $settings->priceThousandsSep;

		if ($sendEmailToAdmin == 'false' && $sendEmailToCustomer == 'false') {
			return false; // no need to generateEmails
		}

		$curSymbol = self::getSymbol($settings->currency);
		$date_format = EventBookingHelpers::convertDateFormat($settings->dateFormat);
		$time_format = $settings->dateFormat;

		// format IDs
		$formattedID = str_pad($eventID, 10, '0', STR_PAD_LEFT);
		$paymentIDFormatted = str_pad($paymentID, 10, '0', STR_PAD_LEFT);

		// get payment data
		$payment = $wpdb->get_row("SELECT * FROM " . self::getTableName("payments")." where id='$paymentID' ");
		$eventID = $payment->event_id;
		$ticketID = $payment->ticket_id;
		$dateID = $payment->date_id;
		$coupon = $payment->coupon;
		$payerName = $payment->name;
		$quantity = $payment->quantity;
		$paymentAmount = $payment->amount;
		$payerEmail = $payment->email;
		$payment_date = $payment->date_paid;
		$txn_id = $payment->txn_id;
		$bookingType = $payment->type;
		$paymentExtras = $payment->extras;

		// format Amount
		$paymentAmount = EventBookingHelpers::currencyPricingFormat($paymentAmount, $curSymbol, $currencyBefore,
			$priceDecimalCount, $priceDecPoint, $priceThousandsSep, '%cost%');

		// get event data
		$event = $wpdb->get_row("SELECT name, info, mapAddress, ownerEmail, emailTemplateID FROM " . self::getTableName("events")." where id='$eventID' ");
		$eventname = stripslashes($event->name);
		$eventDesc = $event->info;
		$eventAddress = $event->mapAddress;
		$eventOwnerEmail = $event->ownerEmail;
		$emailTemplateID = $event->emailTemplateID;

		// get ticket data
		$eventTickets = $wpdb->get_row("SELECT name FROM " . self::getTableName("tickets")." where id='$ticketID'");
		$ticketName = $eventTickets->name;

		// get event occurrence data
		$eventDate = $wpdb->get_row("SELECT start_date, end_date, start_time, end_time FROM " .self::getTableName("eventDates")." where id='$dateID'");
		$startDate = utf8_encode(strftime($date_format, strtotime($eventDate->start_date)));
		$endDate = utf8_encode(strftime($date_format, strtotime($eventDate->end_date)));
		$start_time = date($time_format, strtotime($eventDate->start_time));
		$end_time = date($time_format, strtotime($eventDate->end_time));

		// get coupon data
		if ($coupon != "N.A.") {
			$couponData = $wpdb->get_row("SELECT code, amount FROM " . self::getTableName("coupons")." where code='$coupon'");
			$couponMarkUp ="<p>You used a coupon (".$couponData->code.") and got a ".$couponData->amount." discount.</p>";
		} else {
			$couponMarkUp = "";
		}

		// get QR and Bar code data
		$QRCODE_id = self::generateBookingIdQRCode($paymentID);
		$barcode_id = self::generateBarCode($paymentID);
		$QRCODE_txn_id = self::generateBookingIdQRCode($txn_id);
		$barcode_txn_id = self::generateBarCode($txn_id);

		// populate keywords with data
		$extraFieldsMarkUp = rtrim(str_replace("%","<br/>", $paymentExtras),",");
		$EmailVars = array('%booking_QR_Code%','%transactionID_QR_Code%', '%bar_code%', '%barcode_id%', '%barcode_transaction_id%',
		 "%eventname%","%event_desc%","%event_address%", "%payer_name%","%quantity%", "%ticketName%","%payment_amount%","%currency%", "%couponMarkUp%","%start_time%","%startDate%","%end_time%","%endDate%","%paymentDate%","%paymentID%","%eventid%","%payer_email%","%transaction_id%","%ticketID%","%dateID%","%allExtraFields%","%eventid_formatted%","%bookingType%", "%paymentIDFormatted%");

		$emailVarsValues = array($QRCODE_id, $QRCODE_txn_id, $barcode_id, $barcode_id, $barcode_txn_id,
			$eventname, $eventDesc, $eventAddress, $payerName, $quantity, $ticketName, $paymentAmount,
			$curSymbol, $couponMarkUp, $start_time, $startDate, $end_time, $endDate, $payment_date,
			$paymentID, $eventID, $payerEmail, $txn_id, $ticketID, $dateID, $extraFieldsMarkUp,
			$formattedID, $bookingType, $paymentIDFormatted);

		// add extra fields
		$extraFieldsArr = explode("%", $paymentExtras);
		foreach($extraFieldsArr as $e) {
			$field = explode(":", $e);
			if (count ($field) > 1) {
				array_push($EmailVars, "%".$field[0]."%");
				array_push($emailVarsValues, $field[1]." ");
			}
		}

		// send logic
		if ($type == "refund") {
			$emailData = str_replace($EmailVars, $emailVarsValues, stripslashes($refundEmailTemplate));
		} else {
			if ($emailTemplateID != '-1') {
				$confirmEmailTempalteData = $wpdb->get_row("SELECT subject, message FROM " . self::getTableName("emailTemplates")." where id='$emailTemplateID'");
				if ($confirmEmailTempalteData != null) {
					$confirmationEmailTemplate = $confirmEmailTempalteData->message;
					$emailSubject = $confirmEmailTempalteData->subject;
				}

			}

			$emailData = str_replace($EmailVars, $emailVarsValues, stripslashes($confirmationEmailTemplate));
		}

		$emailData = preg_replace('/%.*%/', '', $emailData)	;

		if ($type == "refund") {
			$forClient = str_replace($EmailVars, $emailVarsValues, stripslashes($refundOwnerEmailTemplate));
		} else {
			$forClient = str_replace($EmailVars, $emailVarsValues, stripslashes($ownerEmailTemplate));
		}

		//$forClient = preg_replace('/%.*%/', '', $forClient)	;
		$toClientSubject = str_replace($EmailVars, $emailVarsValues, $emailSubject);

		if ($sendEmailToCustomer != 'false') {
			self::sendEmail($payerName, $payerEmail, $toClientSubject, $emailData);
		}

		if ($sendEmailToAdmin != 'false' ) {
			$ownerEmail = (self::isValidEmail($eventOwnerEmail)) ? $eventOwnerEmail : $SMTP_EMAIL;
			self::sendEmail($SMTP_NAME, $ownerEmail, $toClientSubject, $forClient);
		}

		return true;
	}

	public static function isValidEmail($email) {
	  return filter_var($email, FILTER_VALIDATE_EMAIL) && preg_match('/@.+\./', $email);
	}

	public static function sendEmail($name, $email, $sub, $msg) {
		require_once( ABSPATH . WPINC . '/pluggable.php');

		global $wpdb;
		$settings = $wpdb->get_row( "SELECT SMTP_PORT, SMTP_HOST, SMTP_EMAIL, SMTP_PASS, emailSSL, email_mode, SMTP_NAME FROM " . self::getTableName("settings") ." where id=1 ");

		$fromEmail = $settings->SMTP_EMAIL;
		$fromName = $settings->SMTP_NAME;

		if ($settings->email_mode == '4') {
			$headers = 'From: '.$fromName.' <'.$settings->SMTP_EMAIL.'>' . "\r\n";
			$headers .= 'Content-Type: text/html; charset="UTF-8" \r\n';
			$stat = wp_mail($email, $sub, $msg, $headers);
			return ($stat) ? 'sent' : 'Error with wp mail';
		} else {
			if (!class_exists('PHPMailer')) require_once dirname( __FILE__ ) . '/class.phpmailer.php';

			try {
				$mail = new PHPMailer(true);

				if ($settings->email_mode == '1') {
					$mail->IsMail();
				} else {
					$mail->IsSMTP();
				}
				$mail->SMTPAuth   = true;

				if ($settings->emailSSL != "false") $mail->SMTPSecure = $settings->emailSSL;

				$mail->Port = $settings->SMTP_PORT;
				$mail->Host = $settings->SMTP_HOST;
				$mail->Username = $settings->SMTP_EMAIL;
				$mail->Password = $settings->SMTP_PASS;


				$mail->AddReplyTo($fromEmail, $fromName);
				$mail->From = $fromEmail;
				$mail->FromName = $fromName;

				$mail->AddAddress($email);
				$mail->Subject = $sub;

				$mail->AltBody = "To view the message, please use an HTML compatible email viewer!";

				$mail->MsgHTML($msg);
				$mail->IsHTML(true);
				// $mail->CharSet = 'UTF-8';

				 if (!$mail->Send()){
					return $mail->ErrorInfo;
				 }

				 return  "sent";
			} catch (phpmailerException $e) {
				return  "Exception Error: ".$e->errorMessage() ;
			}
		}

 	}

	public static function getLoaderStyle($color, $color2) {
	 return '.fountainG{background-color:'.$color.';}
			@-moz-keyframes bounce_fountainG{
			0%{
			-moz-transform:scale(1);
			background-color:'.$color.';
			}
			100%{
			-moz-transform:scale(.3);
			background-color:'.$color2.';
			}}
			@-webkit-keyframes bounce_fountainG{
			0%{
			-webkit-transform:scale(1);
			background-color:'.$color.';
			}
			100%{
			-webkit-transform:scale(.3);
			background-color:'.$color2.';
			}}@-ms-keyframes bounce_fountainG{
			0%{
			-ms-transform:scale(1);
			background-color:'.$color.';
			}
			100%{
			-ms-transform:scale(.3);
			background-color:'.$color2.';
			}}@-o-keyframes bounce_fountainG{
			0%{
			-o-transform:scale(1);
			background-color:'.$color.';
			}
			100%{
			-o-transform:scale(.3);
			background-color:'.$color2.';
			}}@keyframes bounce_fountainG{
			0%{
			transform:scale(1);
			background-color:'.$color.';
			}
			100%{
			transform:scale(.3);
			background-color:'.$color2.';
			}
			}';
	}

	public static function getModalStyles($settings) {
		$overlayAlpha = intval($settings->popupOverlayAlpha);

		$GoogleCalfontStyle = ($settings->addToCalendarTextFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->addToCalendarTextFontStyle.';';

		$GoogleCalToRight = ($settings->addToCalendarAlign == "right")?'right:0;':'';

		$style = '<style>
		 .eb_frontend .addToCalDiv{'.$GoogleCalToRight.' }
		 a.addToGoogleCal{color:'.$settings->addToCalendarTextColor.'; font-size:'.$settings->addToCalendarTextFontSize.'px; '.$GoogleCalfontStyle.' margin-left:'.$settings->addToCalendarMarginSide.'px; margin-right:'.$settings->addToCalendarMarginSide.'px; margin-bottom:'.$settings->addToCalendarMarginBottom.'px;}
		 a.addToGoogleCal:hover{color:'.$settings->addToCalendarTextHoverColor.';}
		.ebp-overlay{background: '.$settings->modalOverlayColor.';}';

		if (!($overlayAlpha == 100 &&  strcasecmp($settings->modalMainColor, $settings->modalOverlayColor) == 0)) {
		 $style.=' .ebp-content, .ebp-show.ebp-fullpage .ebp-content {background:'.$settings->modalMainColor.';}';
		}

	 $style .= '.ebp-show ~ .ebp-overlay ,
	 		.ebp-show.ebp-fullpage ~ .ebp-overlay {opacity:'.(intval($settings->popupOverlayAlpha)/100).'}
		.ebp-content ,
		.ebp-content .spotsleft,
		.ebp-content .cd-dropdown > span,
		.ebp-content .offlineloader,.ebp-content .optCol span,.ebp-content a.boxBtns,
		.ebp-content .title,
		.ebp-content a.book, .ebp-content a.paypalPay,.ebp-content a.checking,
		.ebp-content .cd-active.cd-dropdown ul li span:hover
		{color:'.$settings->modal_txtColor.';}
		.ebp-content input,.ebp-content textarea, .ebp-content select{color:'.$settings->modal_input_txtColor.' !important; background:'.self::hex2rgba($settings->modal_input_bgColor,intval($settings->modal_input_bgColorAlpha)/100).' !important;}
		.ebp-content form span.label a{color:'.$settings->modal_input_txtColor.' !important;}
		 .ebp-content select option{color:#000;}
		.ebp-content input:hover, .ebp-content input:focus,.ebp-content textarea:hover, .ebp-content textarea:focus{color:'.$settings->modal_inputHover_txtColor.' !important; background:'.self::hex2rgba($settings->modal_inputHover_bgColorHover ,intval($settings->modal_inputHover_bgColorAlpha )/100).' !important;}
		.ebp-content input[disabled]:hover{color:'.$settings->modal_input_txtColor.' !important; background:'.self::hex2rgba($settings->modal_input_bgColor,intval($settings->modal_input_bgColorAlpha)/100).' !important;}
		.ebp-content .checkBoxStyle label{background:'.self::hex2rgba($settings->modal_input_bgColor ,intval($settings->modal_input_bgColorAlpha )/100).' ;}
		.ebp-content .checkBoxStyle label.check:after {border: 3px solid '.$settings->checkBoxColor.'; border-top: none;border-right: none;}
		.ebp-content .checkBoxStyle label.dot:after {background-color: '.$settings->checkBoxColor.';}
		.ebp-content .inputholder{color:'.$settings->checkBoxTextColor.';}
		.ebp-content .cd-dropdown > span:after ,
		.ebp-content .optCol,
		.ebp-content a.checking {color:'.self::hex2rgba($settings->modal_txtColor,0.8).';}
		.ebp-content .cd-active.cd-dropdown ul li span:hover {
			background: '.$settings->modal_selectHoverColor.';
			color: '.$settings->modal_selectTxtHoverColor.';
		}
		.ebp-content .cd-active.cd-dropdown > span {
			color: '.$settings->modal_selectHoverColor.';
		}
	</style>';
		return $style;
	}


	public static function getStyling($cust_width = NULL, $id) {
		global $wpdb;
		$settings = $wpdb->get_row( "SELECT * FROM " . EventBookingHelpers::getTableName("settings")." where id='$id' ");

		if ($cust_width != NULL)
			$thewidth = $cust_width;
		else if ($id == 1 || $id == 3)
			$thewidth = $settings->boxWidth;
		else if ($id == 2)
			$thewidth = $settings->cal_width;

		$originalWidth = $thewidth;

		if ($id == 2) {
			$thewidth = intval($thewidth) - 2 * intval($settings->cal_paddingSides);
		}

		$innerWidth = (intval($thewidth) / 2 - intval($settings->detailsPaddingSides)-intval($settings->detailsBorderSide));



		if ($settings->boxAlign == "true")
			$boxAlign = 'margin: 0 auto; margin-top: '.$settings->boxMarginTop.'px; margin-bottom: '.$settings->boxMarginBottom.'px;';
		else
			$boxAlign = 'margin: '.$settings->boxMarginTop.'px '.$settings->boxMarginSides.'px; margin-bottom: '.$settings->boxMarginBottom.'px;';


		$boxstyle = 'width:'.$thewidth.'px; max-width: 100%; padding:'.$settings->boxPaddingTop.'px '.$settings->boxPaddingSides.'px; padding-bottom: '.$settings->boxPaddingBottom.'px;  background-color:'.$settings->boxBgColor.';  -webkit-border-radius: '.$settings->boxBorderRadius.'px; -moz-border-radius: '.$settings->boxBorderRadius.'px; border-radius: '.$settings->boxBorderRadius.'px; border:'.$settings->boxBorder.'px solid'.$settings->boxBorderColor.';'.$boxAlign;


		$buyBtnCnt = 'margin: 0 auto; padding-top: '.$settings->btnMarginTop.'px; padding-bottom:'.$settings->btnMarginBottom.'px;';

		$bookBtnStyle = 'background-color:'.$settings->btnBgColor.'; color:'.$settings->btnColor.'; font-size:'.$settings->btnFontSize.'px; height: auto; line-height:'.$settings->btnLineHeight.'px; padding:'.$settings->btnTopPadding.'px '.$settings->btnSidePadding.'px; font-weight:'.$settings->btnFontType.';  -webkit-border-radius: '.$settings->btnBorderRadius.'px; -moz-border-radius: '.$settings->btnBorderRadius.'px; border-radius: '.$settings->btnBorderRadius.'px; border-top:'.$settings->btnBorder.'px solid'.$settings->btnBorderColor.';';

		$btnStyle = array('btn' => $bookBtnStyle, 'cnt' => $buyBtnCnt);

		$titleAignment = 'text-align:'.$settings->titleTextAlign.';';
		if ($settings->titleTextAlign == "center")
			$titleAignment .= 'margin:0 auto;';

		$fontStyle = ($settings->titleFontStyle == "italic") ? 'font-style:italic;' : 'font-weight:'.$settings->titleFontStyle.';';

		$titleStyle = 'color:'.$settings->titleColor.'; font-size:'.$settings->titleFontSize.'px ;line-height:'.$settings->titleLineHeight.'px;'.$fontStyle.' padding:'.$settings->titlePaddingTop.'px '.$settings->titlePaddingSides.'px; padding-bottom:'.$settings->titlePaddingBottom.'px;'.$titleAignment.' margin-top:'.$settings->titleMarginTop.'px; margin-bottom:'.$settings->titleMarginBottom.'px; border-bottom:'.$settings->titleBottomBorder.'px solid '.$settings->titleBottomBorderColor.';' ;


		//date
		$alignment = 'text-align:'.$settings->dateTextAlign.';';
		if ($settings->dateTextAlign == "center")
			$alignment .= 'margin:0 auto;';

		$fontStyle = ($settings->dateFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->dateFontStyle.';';

		$dateStyle = 'color:'.$settings->dateColor.'; font-size:'.$settings->dateFontSize.'px; line-height:120%;'.$fontStyle.' padding:'.$settings->datePaddingTop.'px '.$settings->datePaddingSides.'px; padding-bottom:'.$settings->datePaddingBottom.'px;'.$alignment.' margin-bottom:'.$settings->dateMarginBottom.'px; margin-top:'.$settings->dateMarginTop.'px; border-bottom:'.$settings->dateBorderSize.'px solid '.$settings->dateBorderColor.';' ;

		$fontStyle = ($settings->dateLabelStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->dateLabelStyle.';';

		$dateLabelStyle = 'color:'.$settings->dateLableColor.'; font-size:'.$settings->dateLableSize.'px; line-height:'.$settings->dateLabelLineHeight.'px; '.$fontStyle;

		//date modal
		$alignment = 'text-align:'.$settings->modal_dateTextAlign.';';
		if ($settings->modal_dateTextAlign == "center")
			$alignment .= 'margin:0 auto;';

		$fontStyle = ($settings->modal_dateFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->modal_dateFontStyle.';';

		$modal_dateStyle = 'color:'.$settings->modal_dateColor.'; font-size:'.$settings->modal_dateFontSize.'px; line-height:120% '.$fontStyle.' padding:'.$settings->modal_datePaddingTop.'px '.$settings->modal_datePaddingSides.'px; padding-bottom:'.$settings->modal_datePaddingBottom.'px;'.$alignment.' margin-bottom:'.$settings->modal_dateMarginBottom.'px; margin-top:'.$settings->modal_dateMarginTop.'px;' ;

		$fontStyle = ($settings->modal_dateLabelStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->modal_dateLabelStyle.';';

		$modal_dateLabelStyle = 'color:'.$settings->modal_dateLableColor.'; font-size:'.$settings->modal_dateLableSize.'px; line-height:'.$settings->modal_dateLabelLineHeight.'px; '.$fontStyle;

		//modalTitleStyle
		$fontStyle = ($settings->modal_dateTitleFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->modal_dateTitleFontStyle.';';

		$modalTitleStyle = 'margin-bottom:'.$settings->modal_dateTitleMarginBottom.'px; color: '.$settings->modal_dateTitleColor.'; font-size:'.$settings->modal_dateTitleFontSize.'px; line-height:'.$settings->modal_dateTitleFontLineHeight.'px; '.$fontStyle.' text-align:'.$settings->modal_dateTitleTextAlign;


		$alignment ='text-align:'.$settings->infoTextAlign.';';


		$fontStyle = ($settings->infoFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->infoFontStyle.';';

		$infoStyle = 'color:'.$settings->infoColor.'; font-size:'.$settings->infoFontSize.'px; line-height:'.$settings->infoLineHeight.'px; '.$fontStyle.' padding:'.$settings->infoPaddingTop.'px '.$settings->infoPaddingSides.'px; margin-bottom: 0px; padding-bottom:'.$settings->infoPaddingBottom.'px;'.$alignment.' border-bottom:'.$settings->infoBorderSize.'px solid '.$settings->infoBorderColor.'; overflow:hidden;' ;
		//margin-bottom:'.$settings->infoMarginBottom.'px; margin-top:'.$settings->infoMarginTop.'px;

		$moreDareBtn = 'background-color:'.self::hex2rgba($settings->boxBgColor,.9).';
		-webkit-box-shadow:  0px -5px 10px 0px '.self::hex2rgba($settings->boxBgColor,.8).';
		-moz-box-shadow:  0px -5px 10px 0px '.self::hex2rgba($settings->boxBgColor,.8).';
		box-shadow:  0px -5px 10px 0px rgba'.self::hex2rgba($settings->boxBgColor,.8).';';


		//details
		$fontStyle = ($settings->detailsFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->detailsFontStyle.';';

		$detialsStyle = 'color:'.$settings->detailsColor.'; font-size:'.$settings->detailsFontSize.'px; line-height:'.$settings->detailsFontLineHeight.'px; '.$fontStyle.' padding:'.$settings->detailsPaddingTop.'px '.$settings->detailsPaddingSides.'px; padding-bottom:'.$settings->detailsPaddingBottom.'px; margin-bottom:'.$settings->detailsMarginBottom.'px; margin-top:'.$settings->detailsMarginTop.'px; border-bottom:'.$settings->detailsBorderSize.'px solid '.$settings->detailsBorderColor.';' ;

		$fontStyle = ($settings->detailsLabelStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->detailsLabelStyle.';';

		$detialsLabelStyle = 'color:'.$settings->detailsLableColor.'; font-size:'.$settings->detailsLableSize.'px; line-height:'.$settings->detailsLabelLineHeight.'px; height:'.$settings->detailsLabelLineHeight.'px;'.$fontStyle;

		//costs

		$spotsStyle = '';
		$costStyle = '';


		$imgWidth = intval($thewidth)-intval($settings->imageMarginSides)*2;
		$imageStyle = 'width: 100%; margin: 0px '.$settings->imageMarginSides.'px; margin-top: '.$settings->imageMarginTop.'px; margin-bottom: '.$settings->imageMarginBottom.'px;';

		$calStyle = 'max-width:'.$originalWidth.'px;';

		$calBodyStyle = 'border: '.$settings->cal_sideBorder.'px solid '.$settings->cal_sideBorderColor.'; border-top: '.$settings->cal_topBorder.'px solid '.$settings->cal_topBorderColor.'; border-bottom: '.$settings->cal_bottomBorder.'px solid '.$settings->cal_bottomBorderColor.';';

		$calCloseStyle = 'border-top: '.$settings->cal_topBorder.'px solid '.$settings->cal_topBorderColor.';';


		$innerWidthEvent= $originalWidth;
		$eventContentStyling='width: 100%; padding:0px '.$settings->cal_paddingSides.'px;';


		$modalBtn='margin-top: '.$settings->modal_btnMarginTop.'px; color:'.$settings->modal_btnTxtColor.'; font-size:'.$settings->modal_btnFontSize.'px; height:auto; line-height:'.$settings->modal_btnLineHeight.'px; padding:'.$settings->modal_btnTopPadding.'px '.$settings->modal_btnSidePadding.'px; font-weight:'.$settings->modal_btnFontType.'; -webkit-border-radius: '.$settings->modal_btnBorderRadius.'px; -moz-border-radius: '.$settings->modal_btnBorderRadius.'px; border-radius: '.$settings->modal_btnBorderRadius.'px; ';

		$fontStyle=($settings->modal_titleFontType == "italic")?'font-style:italic;':'font-weight:'.$settings->modal_titleFontType.';';

		$modalTitle='margin-bottom: '.$settings->modal_titleMarginBottom.'px; font-size:'.$settings->modal_titleSize.'px; line-height:'.$settings->modal_titleLineHeight.'px; '.$fontStyle;


		$modalInput = 'font-size: '.$settings->modal_input_fontSize.'px; line-height: '.$settings->modal_input_lineHeight.'px;  padding: '.$settings->modal_input_topPadding.'px 0px ;margin-bottom: '.$settings->modal_input_space.'px; ';
		$modalInputSpace ='margin-bottom: '.$settings->modal_input_space.'px;';
		$modalCheckSpace = 'margin-bottom: '.$settings->checkBoxMarginBottom.'px; margin-top: '.$settings->checkBoxMarginTop.'px;';
		$modalInputArea = 'font-size: '.$settings->modal_input_fontSize.'px; line-height: '.$settings->modal_input_lineHeight.'px; padding: '.$settings->modal_input_topPadding.'px 0px ;margin-bottom: '.$settings->modal_input_space.'px; ';
		$moreDatefontStyle = ($settings->infoFontStyle == "italic")?'font-style:italic;':'font-weight:'.$settings->infoFontStyle.';';


		return	array('btn'=>$btnStyle,'box'=>$boxstyle,"title"=>$titleStyle,"date"=>$dateStyle,"dateLabel"=>$dateLabelStyle,
				"modal_date"=>$modal_dateStyle,"modal_dateLabel"=>$modal_dateLabelStyle,
				 "details"=>$detialsStyle, "detailsLabel"=>$detialsLabelStyle,"costStyle"=>$costStyle,"spotsStyle"=>$spotsStyle,
				"width"=>$originalWidth,
				"imageStyle"=>$imageStyle,
				"imgWidth"=>$imgWidth,
				"info"=>$infoStyle,
				"infoColor" =>$settings->infoColor,
				"infoPaddingSides" =>$settings->infoPaddingSides,
				'moreDareBtn'=>$moreDareBtn,
				"calStyle"=>$calStyle,
				"calBodyStyle"=>$calBodyStyle,
				"calCloseStyle"=>$calCloseStyle,
				"modalBtn"=>$modalBtn,
				"modalTitle"=>$modalTitle,
				"modalInput"=>$modalInput,
				"modalInputArea"=>$modalInputArea,
				"modalInputSpace"=>$modalInputSpace,
				"modalCheckSpace"=>$modalCheckSpace,
				"innerWidth"=>$thewidth,
				"settings"=>$settings,
				"showPrice"=>$settings->showPrice,
				"bookedTxt"=>$settings->bookedTxt,
				"passedTxt"=>$settings->passedTxt,
				"btnTxt"=>$settings->btnTxt,
				"dateEnds"=>$settings->includeEndsOn,
				"datePaddingBottom"=>$settings->datePaddingBottom,
				"paypalAccount"=>$settings->paypalAccount,
				"imageCrop"=>$settings->imageCrop,
				"imageHeight"=>$settings->imageHeight,
				"infoHeight"=>$settings->infoMaxHeight,
				"displayWeekAbbr"=>$settings->cal_displayWeekAbbr,
				"displayMonthAbbr"=>$settings->cal_displayMonthAbbr,
				"startIn"=>$settings->cal_startIn,
				"calColor"=>$settings->cal_color,
				"cal_bgColor"=>$settings->cal_bgColor,
				"cal_boxColor"=>$settings->cal_boxColor,
				"cal_dateColor"=>$settings->cal_dateColor,
				"cal_titleBgColor"=>$settings->cal_titleBgColor,
				"eventContentStyling"=>$eventContentStyling,
				"cpp_header_image"=>$settings->cpp_header_image,
				"cpp_headerback_color"=>$settings->cpp_headerback_color,
				"cpp_headerborder_color"=>$settings->cpp_headerborder_color,
				"cpp_logo_image"=>$settings->cpp_logo_image,
				"cpp_payflow_color"=>$settings->cpp_payflow_color,
				"modalColor"=>$settings->modalMainColor,
				"modalNameTxt"=>$settings->modalNameTxt,
				"modalEmailTxt"=>$settings->modalEmailTxt,
				"modalPhoneTxt"=>$settings->modalPhoneTxt,
				"modalAddressTxt"=>$settings->modalAddressTxt,
				"currency"=>$settings->currency,
				"sandbox"=>$settings->sandbox,
				"modalBookText"=>$settings->modalBookText,
				"requirePhone"=>$settings->requirePhone,
				"requireAddress"=>$settings->requireAddress,
				"moreDatesOn"=>$settings->moreDateOn,
				"moreDatePassed"=>$settings->moreDatePassed,
				"moreDateUpcoming"=>$settings->moreDateUpcoming,
				"moreDateMarginTop"=>$settings->moreDateMarginTop,
				"moreDateColor"=>$settings->moreDateColor,
				"moreDateTextAlign"=>$settings->moreDateTextAlign,
				"moreDateSize"=>$settings->moreDateSize,
				"moreDateLineHeight"=>$settings->moreDateLineHeight,
				"moreDatefontStyle"=>$moreDatefontStyle,
				"moreDateHoverColor"=>$settings->moreDateHoverColor,
				"moreDateTxt"=>$settings->moreDateTxt,
				"moreDateSectionMarginBottom"=>$settings->moreDateSectionMarginBottom,
				"modalTitleStyle"=>$modalTitleStyle,
				"modal_txtColor" => $settings->modal_txtColor,
				"couponsEnabled"=>$settings->couponsEnabled,
				"multipleBookings"=>$settings->multipleBookings,
				"dateFormat"=>$settings->dateFormat,
				"timeFormat"=>$settings->timeFormat,
				"statsOnTxt"=>$settings->statsOnTxt,
				"endsOnTxt"=>$settings->endsOnTxt,
				"spotsLeftTxt"=>$settings->spotsLeftTxt,
				"modalSpotsLeftTxt"=>$settings->modalSpotsLeftTxt ,
				"modalQuantityTxt"=>$settings->modalQuantityTxt ,
				"modalSingleCostTxt"=>$settings->modalSingleCostTxt,
				"modalTotalCostTxt"=>$settings->modalTotalCostTxt,
				"eventBookedTxt"=>$settings->eventBookedTxt,
				"bookingTxt"=>$settings->bookingTxt,
				"ExpandTextTxt"=>$settings->ExpandTextTxt,
				"closeTextTxt"=>$settings->closeTextTxt,
				"termsLink"=>$settings->termsLink
		);

	}


	public static function getSymbol($code = 'USD') {
	   $currencies = array(
			'RUB' => array('name' => "Russian ruble", 'symbol' => "руб", 'ASCII' => ""),

			'AUD' => array('name' => "Australian Dollar", 'symbol' => "A$", 'ASCII' => "A&#36;"),

			'CAD' => array('name' => "Canadian Dollar", 'symbol' => "$", 'ASCII' => "&#36;"),

			'CZK' => array('name' => "Czech Koruna", 'symbol' => "Kč", 'ASCII' => ""),

			'DKK' => array('name' => "Danish Krone", 'symbol' => "Kr", 'ASCII' => ""),

			'EUR' => array('name' => "Euro", 'symbol' => "€", 'ASCII' => "&#128;"),

			'HKD' => array('name' => "Hong Kong Dollar", 'symbol' => "$", 'ASCII' => "&#36;"),

			'HUF' => array('name' => "Hungarian Forint", 'symbol' => "Ft", 'ASCII' => ""),

			'ILS' => array('name' => "Israeli New Sheqel", 'symbol' => "₪", 'ASCII' => "&#8361;"),

			'JPY' => array('name' => "Japanese Yen", 'symbol' => "¥", 'ASCII' => "&#165;"),

			'MXN' => array('name' => "Mexican Peso", 'symbol' => "$", 'ASCII' => "&#36;"),

			'NOK' => array('name' => "Norwegian Krone", 'symbol' => "Kr", 'ASCII' => ""),

			'NZD' => array('name' => "New Zealand Dollar", 'symbol' => "$", 'ASCII' => "&#36;"),

			'PHP' => array('name' => "Philippine Peso", 'symbol' => "₱", 'ASCII' => ""),

			'PLN' => array('name' => "Polish Zloty", 'symbol' => "zł", 'ASCII' => ""),

			'GBP' => array('name' => "Pound Sterling", 'symbol' => "£", 'ASCII' => "&#163;"),

			'SGD' => array('name' => "Singapore Dollar", 'symbol' => "$", 'ASCII' => "&#36;"),

			'SEK' => array('name' => "Swedish Krona", 'symbol' => "kr", 'ASCII' => ""),

			'CHF' => array('name' => "Swiss Franc", 'symbol' => "CHF", 'ASCII' => ""),

			'TWD' => array('name' => "Taiwan New Dollar", 'symbol' => "NT$", 'ASCII' => "NT&#36;"),

			'THB' => array('name' => "Thai Baht", 'symbol' => "฿", 'ASCII' => "&#3647;"),

			'USD' => array('name' => "U.S. Dollar", 'symbol' => "$", 'ASCII' => "&#36;"),

			'TLR' => array('name' => "Turkish Lira (TLR)", 'symbol' => "₺", 'ASCII' => "&#8378;"),

			'TRY' => array('name' => "Turkish Lira (TRY)", 'symbol' => "₺", 'ASCII' => "&#8378;"),

			'MYR' => array('name' => "Malaysia Ringgit", 'symbol' => "RM", 'ASCII' => ""),

			'BRL' => array('name' => "Brazilian Rea", 'symbol' => "BRL", 'ASCII' => ""),

			'LEM' => array('name' => "Lempira", 'symbol' => "L.", 'ASCII' => ""),

			'IND' => array('name' => "Indonesian (Rp)", 'symbol' => "Rp", 'ASCII' => ""),

			'LTL' => array('name' => "Lithuanian Litas", 'symbol' => "Ltl", 'ASCII' => ""),

			'INR' => array('name' => "Indian Rupee", 'symbol' => "₹", 'ASCII' => ""),

			'ZAR' => array('name' => "South African", 'symbol' => "R", 'ASCII' => ""),

			'VEF' => array('name' => "Venezuelan Bolívar", 'symbol' => "Bs.", 'ASCII' => ""),

			'KRW' => array('name' => "Korea Won", 'symbol' => "&#65510;", 'ASCII' => "&#65510;"),

			'VND' => array('name' => "Vietnam", 'symbol' => "đ", 'ASCII' => ""),

			'GHC' => array('name' => "Ghana Cedis", 'symbol' => "GH¢", 'ASCII' => ""),

			'RWF' => array('name' => "Rwandan Franc", 'symbol' => "RWF", 'ASCII' => "")


		);



		return (string) $currencies[$code]['symbol'];
  }


	public static function hex2rgba($color, $opacity = false) {
		$default = 'rgb(0,0,0)';
		//Return default if no color provided
		if (empty($color)) return $default;

		//Sanitize $color if "#" is provided
		if ($color[0] == '#' ) {
			$color = substr( $color, 1 );
		}

		//Check if color has 6 or 3 characters and get values
		if (strlen($color) == 6) {
			$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
		} else if ( strlen( $color ) == 3 ) {
			$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
		} else {
			return $default;
		}

		//Convert hexadec to rgb
		$rgb =  array_map('hexdec', $hex);

		//Check if opacity is set(rgba or rgb)
		if ($opacity) {
			if (abs($opacity) > 1)
				$opacity = 1.0;
			$output = 'rgba('.implode(",", $rgb).','.$opacity.')';
		} else {
			$output = 'rgb('.implode(",", $rgb).')';
		}

		//Return rgb(a) color string
		return $output;
	}


	public static function convertDateFormat ($format){
	  $old = array('m', 'n', 'Y', 'y', 'F', 'l', 'D', 'd', 'j', 'M', 'S');
	  $new = array('%m','%m', '%Y', '%y', '%B', '%A', '%a', '%d', '%d', '%b', '');
		$format = str_replace($old, $new, $format);
		$format = str_replace('%%', '%', $format);
		return $format;
	}

}


?>
